RuntimePlugin

Trait RuntimePlugin 

pub trait RuntimePlugin:
    Debug
    + Send
    + Sync {
    // Provided methods
    fn order(&self) -> Order { ... }
    fn config(&self) -> Option<FrozenLayer> { ... }
    fn runtime_components(
        &self,
        current_components: &RuntimeComponentsBuilder,
    ) -> Cow<'_, RuntimeComponentsBuilder> { ... }
}
Runtime plugin trait

A RuntimePlugin is the unit of configuration for augmenting the client with new behavior.

Runtime plugins can register interceptors, set runtime components, and modify configuration.

Provided Methods

fn order(&self) -> Order

Runtime plugin ordering.

There are two runtime plugin “levels” that run in the following order:

  1. Service runtime plugins - runtime plugins that pertain to the entire service.
  2. Operation runtime plugins - runtime plugins relevant only to a single operation.

This function is used to determine runtime plugin order within those levels. So regardless of this Order value, service runtime plugins will still always execute before operation runtime plugins. However, Defaults service runtime plugins will run before Overrides service runtime plugins.

fn config(&self) -> Option<FrozenLayer>

Optionally returns additional config that should be added to the ConfigBag.

As a best practice, a frozen layer should be stored on the runtime plugin instance as a member, and then cloned upon return since that clone is cheap. Constructing a new Layer and freezing it will require a lot of allocations.

fn runtime_components( &self, current_components: &RuntimeComponentsBuilder, ) -> Cow<'_, RuntimeComponentsBuilder>

Returns a RuntimeComponentsBuilder to incorporate into the final runtime components.

The order of runtime plugins determines which runtime components “win”. Components set by later runtime plugins will override those set by earlier runtime plugins.

If no runtime component changes are desired, just return an empty builder.

This method returns a Cow for flexibility. Some implementers may want to store the components builder as a member and return a reference to it, while others may need to create the builder every call. If possible, returning a reference is preferred for performance.

Components configured by previous runtime plugins are in the current_components argument, and can be used to create nested/wrapped components, such as a connector calling into an inner (customer provided) connector.

Implementations on Foreign Types

Source

impl RuntimePlugin for PayloadSigningOverrideRuntimePlugin

Source

impl RuntimePlugin for NoAuthRuntimePluginV2

Source

impl RuntimePlugin for EnforceContentLengthRuntimePlugin

Source

impl RuntimePlugin for MetricsRuntimePlugin

Source

impl RuntimePlugin for CannedResponseDeserializer

Source

impl RuntimePlugin for CannedRequestSerializer

Implementors

Source

impl RuntimePlugin for ConvertRecoveryPointToSnapshot

Source

impl RuntimePlugin for CreateCustomDomainAssociation

Source

impl RuntimePlugin for CreateEndpointAccess

Source

impl RuntimePlugin for CreateNamespace

Source

impl RuntimePlugin for CreateReservation

Source

impl RuntimePlugin for CreateScheduledAction

Source

impl RuntimePlugin for CreateSnapshot

Source

impl RuntimePlugin for CreateSnapshotCopyConfiguration

Source

impl RuntimePlugin for CreateUsageLimit

Source

impl RuntimePlugin for CreateWorkgroup

Source

impl RuntimePlugin for DeleteCustomDomainAssociation

Source

impl RuntimePlugin for DeleteEndpointAccess

Source

impl RuntimePlugin for DeleteNamespace

Source

impl RuntimePlugin for DeleteResourcePolicy

Source

impl RuntimePlugin for DeleteScheduledAction

Source

impl RuntimePlugin for DeleteSnapshot

Source

impl RuntimePlugin for DeleteSnapshotCopyConfiguration

Source

impl RuntimePlugin for DeleteUsageLimit

Source

impl RuntimePlugin for DeleteWorkgroup

Source

impl RuntimePlugin for GetCredentials

Source

impl RuntimePlugin for GetCustomDomainAssociation

Source

impl RuntimePlugin for GetEndpointAccess

Source

impl RuntimePlugin for GetIdentityCenterAuthToken

Source

impl RuntimePlugin for GetNamespace

Source

impl RuntimePlugin for GetRecoveryPoint

Source

impl RuntimePlugin for GetReservation

Source

impl RuntimePlugin for GetReservationOffering

Source

impl RuntimePlugin for GetResourcePolicy

Source

impl RuntimePlugin for GetScheduledAction

Source

impl RuntimePlugin for GetSnapshot

Source

impl RuntimePlugin for GetTableRestoreStatus

Source

impl RuntimePlugin for GetTrack

Source

impl RuntimePlugin for GetUsageLimit

Source

impl RuntimePlugin for GetWorkgroup

Source

impl RuntimePlugin for ListCustomDomainAssociations

Source

impl RuntimePlugin for ListEndpointAccess

Source

impl RuntimePlugin for ListManagedWorkgroups

Source

impl RuntimePlugin for ListNamespaces

Source

impl RuntimePlugin for ListRecoveryPoints

Source

impl RuntimePlugin for ListReservationOfferings

Source

impl RuntimePlugin for ListReservations

Source

impl RuntimePlugin for ListScheduledActions

Source

impl RuntimePlugin for ListSnapshotCopyConfigurations

Source

impl RuntimePlugin for ListSnapshots

Source

impl RuntimePlugin for ListTableRestoreStatus

Source

impl RuntimePlugin for ListTagsForResource

Source

impl RuntimePlugin for ListTracks

Source

impl RuntimePlugin for ListUsageLimits

Source

impl RuntimePlugin for ListWorkgroups

Source

impl RuntimePlugin for PutResourcePolicy

Source

impl RuntimePlugin for RestoreFromRecoveryPoint

Source

impl RuntimePlugin for RestoreFromSnapshot

Source

impl RuntimePlugin for RestoreTableFromRecoveryPoint

Source

impl RuntimePlugin for RestoreTableFromSnapshot

Source

impl RuntimePlugin for TagResource

Source

impl RuntimePlugin for UntagResource

Source

impl RuntimePlugin for UpdateCustomDomainAssociation

Source

impl RuntimePlugin for UpdateEndpointAccess

Source

impl RuntimePlugin for UpdateLakehouseConfiguration

Source

impl RuntimePlugin for UpdateNamespace

Source

impl RuntimePlugin for UpdateScheduledAction

Source

impl RuntimePlugin for UpdateSnapshot

Source

impl RuntimePlugin for UpdateSnapshotCopyConfiguration

Source

impl RuntimePlugin for UpdateUsageLimit

Source

impl RuntimePlugin for UpdateWorkgroup

Source

impl RuntimePlugin for StaticRuntimePlugin

Source

impl RuntimePlugin for SharedRuntimePlugin