#[non_exhaustive]
pub enum Error { AccessDeniedException(AccessDeniedException), ConflictException(ConflictException), InsufficientCapacityException(InsufficientCapacityException), InternalServerException(InternalServerException), InvalidPaginationException(InvalidPaginationException), ResourceNotFoundException(ResourceNotFoundException), ServiceQuotaExceededException(ServiceQuotaExceededException), ThrottlingException(ThrottlingException), TooManyTagsException(TooManyTagsException), ValidationException(ValidationException), Unhandled(Unhandled), }
All possible error types for this service.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


AccessDeniedException(AccessDeniedException)

You do not have sufficient access to perform this action.



ConflictException(ConflictException)

The submitted action has conflicts.



InsufficientCapacityException(InsufficientCapacityException)

There is an insufficient capacity to perform the action.



InternalServerException(InternalServerException)

The request processing has failed because of an unknown error, exception or failure.



InvalidPaginationException(InvalidPaginationException)

The provided pagination token is invalid.



ResourceNotFoundException(ResourceNotFoundException)

The resource could not be found.



ServiceQuotaExceededException(ServiceQuotaExceededException)

The service limit was exceeded.



ThrottlingException(ThrottlingException)

The request was denied due to request throttling.



TooManyTagsException(TooManyTagsException)

The request exceeded the number of tags allowed for a resource.



ValidationException(ValidationException)

The input failed to satisfy the constraints specified by an AWS service.



Unhandled(Unhandled)

An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).