#[non_exhaustive]pub struct CreateEndpointAccessInputBuilder { /* private fields */ }Expand description
A builder for CreateEndpointAccessInput.
Implementations
Sourceimpl CreateEndpointAccessInputBuilder
impl CreateEndpointAccessInputBuilder
Sourcepub fn endpoint_name(self, input: impl Into<String>) -> Self
pub fn endpoint_name(self, input: impl Into<String>) -> Self
The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
This field is required.Sourcepub fn set_endpoint_name(self, input: Option<String>) -> Self
pub fn set_endpoint_name(self, input: Option<String>) -> Self
The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
Sourcepub fn get_endpoint_name(&self) -> &Option<String>
pub fn get_endpoint_name(&self) -> &Option<String>
The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
Sourcepub fn subnet_ids(self, input: impl Into<String>) -> Self
pub fn subnet_ids(self, input: impl Into<String>) -> Self
Appends an item to subnet_ids.
To override the contents of this collection use set_subnet_ids.
The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
Sourcepub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self
The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
Sourcepub fn get_subnet_ids(&self) -> &Option<Vec<String>>
pub fn get_subnet_ids(&self) -> &Option<Vec<String>>
The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
Sourcepub fn workgroup_name(self, input: impl Into<String>) -> Self
pub fn workgroup_name(self, input: impl Into<String>) -> Self
The name of the workgroup to associate with the VPC endpoint.
This field is required.Sourcepub fn set_workgroup_name(self, input: Option<String>) -> Self
pub fn set_workgroup_name(self, input: Option<String>) -> Self
The name of the workgroup to associate with the VPC endpoint.
Sourcepub fn get_workgroup_name(&self) -> &Option<String>
pub fn get_workgroup_name(&self) -> &Option<String>
The name of the workgroup to associate with the VPC endpoint.
Sourcepub fn vpc_security_group_ids(self, input: impl Into<String>) -> Self
pub fn vpc_security_group_ids(self, input: impl Into<String>) -> Self
Appends an item to vpc_security_group_ids.
To override the contents of this collection use set_vpc_security_group_ids.
The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
Sourcepub fn set_vpc_security_group_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_vpc_security_group_ids(self, input: Option<Vec<String>>) -> Self
The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
Sourcepub fn get_vpc_security_group_ids(&self) -> &Option<Vec<String>>
pub fn get_vpc_security_group_ids(&self) -> &Option<Vec<String>>
The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
Sourcepub fn owner_account(self, input: impl Into<String>) -> Self
pub fn owner_account(self, input: impl Into<String>) -> Self
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn set_owner_account(self, input: Option<String>) -> Self
pub fn set_owner_account(self, input: Option<String>) -> Self
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn get_owner_account(&self) -> &Option<String>
pub fn get_owner_account(&self) -> &Option<String>
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn build(self) -> Result<CreateEndpointAccessInput, BuildError>
pub fn build(self) -> Result<CreateEndpointAccessInput, BuildError>
Consumes the builder and constructs a CreateEndpointAccessInput.
Sourceimpl CreateEndpointAccessInputBuilder
impl CreateEndpointAccessInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateEndpointAccessOutput, SdkError<CreateEndpointAccessError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateEndpointAccessOutput, SdkError<CreateEndpointAccessError, HttpResponse>>
Sends a request with this input using the given client.