#[non_exhaustive]pub struct CreateEndpointAccessInput {
pub endpoint_name: Option<String>,
pub subnet_ids: Option<Vec<String>>,
pub workgroup_name: Option<String>,
pub vpc_security_group_ids: Option<Vec<String>>,
pub owner_account: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.endpoint_name: Option<String>The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
subnet_ids: Option<Vec<String>>The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
workgroup_name: Option<String>The name of the workgroup to associate with the VPC endpoint.
vpc_security_group_ids: Option<Vec<String>>The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
owner_account: Option<String>The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Implementations
Sourceimpl CreateEndpointAccessInput
impl CreateEndpointAccessInput
Sourcepub fn endpoint_name(&self) -> Option<&str>
pub fn endpoint_name(&self) -> Option<&str>
The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().
Sourcepub fn workgroup_name(&self) -> Option<&str>
pub fn workgroup_name(&self) -> Option<&str>
The name of the workgroup to associate with the VPC endpoint.
Sourcepub fn vpc_security_group_ids(&self) -> &[String]
pub fn vpc_security_group_ids(&self) -> &[String]
The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .vpc_security_group_ids.is_none().
Sourcepub fn owner_account(&self) -> Option<&str>
pub fn owner_account(&self) -> Option<&str>
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourceimpl CreateEndpointAccessInput
impl CreateEndpointAccessInput
Sourcepub fn builder() -> CreateEndpointAccessInputBuilder
pub fn builder() -> CreateEndpointAccessInputBuilder
Creates a new builder-style object to manufacture CreateEndpointAccessInput.