#[non_exhaustive]pub enum CreateNamespaceError {
ConflictException(ConflictException),
InternalServerException(InternalServerException),
TooManyTagsException(TooManyTagsException),
ValidationException(ValidationException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateNamespaceError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConflictException(ConflictException)
The submitted action has conflicts.
InternalServerException(InternalServerException)
The request processing has failed because of an unknown error, exception or failure.
TooManyTagsException(TooManyTagsException)
The request exceeded the number of tags allowed for a resource.
ValidationException(ValidationException)
The input failed to satisfy the constraints specified by an AWS service.
Unhandled(Unhandled)
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
sourceimpl CreateNamespaceError
impl CreateNamespaceError
sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateNamespaceError::Unhandled variant from any error type.
sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateNamespaceError::Unhandled variant from a ::aws_smithy_types::error::ErrorMetadata.
sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateNamespaceError::ConflictException.
sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is CreateNamespaceError::InternalServerException.
Returns true if the error kind is CreateNamespaceError::TooManyTagsException.
sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is CreateNamespaceError::ValidationException.