#[non_exhaustive]pub struct CreateReservationInput {
pub capacity: Option<i32>,
pub offering_id: Option<String>,
pub client_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.capacity: Option<i32>The number of Redshift Processing Units (RPUs) to reserve.
offering_id: Option<String>The ID of the offering associated with the reservation. The offering determines the payment schedule for the reservation.
client_token: Option<String>A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. This token must be a valid UUIDv4 value. For more information about idempotency, see Making retries safe with idempotent APIs .
Implementations
Sourceimpl CreateReservationInput
impl CreateReservationInput
Sourcepub fn capacity(&self) -> Option<i32>
pub fn capacity(&self) -> Option<i32>
The number of Redshift Processing Units (RPUs) to reserve.
Sourcepub fn offering_id(&self) -> Option<&str>
pub fn offering_id(&self) -> Option<&str>
The ID of the offering associated with the reservation. The offering determines the payment schedule for the reservation.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. This token must be a valid UUIDv4 value. For more information about idempotency, see Making retries safe with idempotent APIs .
Sourceimpl CreateReservationInput
impl CreateReservationInput
Sourcepub fn builder() -> CreateReservationInputBuilder
pub fn builder() -> CreateReservationInputBuilder
Creates a new builder-style object to manufacture CreateReservationInput.