#[non_exhaustive]pub struct CreateSnapshotCopyConfigurationInput {
pub namespace_name: Option<String>,
pub destination_region: Option<String>,
pub snapshot_retention_period: Option<i32>,
pub destination_kms_key_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespace_name: Option<String>The name of the namespace to copy snapshots from.
destination_region: Option<String>The destination Amazon Web Services Region that you want to copy snapshots to.
snapshot_retention_period: Option<i32>The retention period of the snapshots that you copy to the destination Amazon Web Services Region.
destination_kms_key_id: Option<String>The KMS key to use to encrypt your snapshots in the destination Amazon Web Services Region.
Implementations
Sourceimpl CreateSnapshotCopyConfigurationInput
impl CreateSnapshotCopyConfigurationInput
Sourcepub fn namespace_name(&self) -> Option<&str>
pub fn namespace_name(&self) -> Option<&str>
The name of the namespace to copy snapshots from.
Sourcepub fn destination_region(&self) -> Option<&str>
pub fn destination_region(&self) -> Option<&str>
The destination Amazon Web Services Region that you want to copy snapshots to.
Sourcepub fn snapshot_retention_period(&self) -> Option<i32>
pub fn snapshot_retention_period(&self) -> Option<i32>
The retention period of the snapshots that you copy to the destination Amazon Web Services Region.
Sourcepub fn destination_kms_key_id(&self) -> Option<&str>
pub fn destination_kms_key_id(&self) -> Option<&str>
The KMS key to use to encrypt your snapshots in the destination Amazon Web Services Region.
Sourceimpl CreateSnapshotCopyConfigurationInput
impl CreateSnapshotCopyConfigurationInput
Sourcepub fn builder() -> CreateSnapshotCopyConfigurationInputBuilder
pub fn builder() -> CreateSnapshotCopyConfigurationInputBuilder
Creates a new builder-style object to manufacture CreateSnapshotCopyConfigurationInput.