#[non_exhaustive]pub struct CreateUsageLimitInputBuilder { /* private fields */ }Expand description
A builder for CreateUsageLimitInput.
Implementations
Sourceimpl CreateUsageLimitInputBuilder
impl CreateUsageLimitInputBuilder
Sourcepub fn resource_arn(self, input: impl Into<String>) -> Self
pub fn resource_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Amazon Redshift Serverless resource to create the usage limit for.
This field is required.Sourcepub fn set_resource_arn(self, input: Option<String>) -> Self
pub fn set_resource_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Amazon Redshift Serverless resource to create the usage limit for.
Sourcepub fn get_resource_arn(&self) -> &Option<String>
pub fn get_resource_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Amazon Redshift Serverless resource to create the usage limit for.
Sourcepub fn usage_type(self, input: UsageLimitUsageType) -> Self
pub fn usage_type(self, input: UsageLimitUsageType) -> Self
The type of Amazon Redshift Serverless usage to create a usage limit for.
This field is required.Sourcepub fn set_usage_type(self, input: Option<UsageLimitUsageType>) -> Self
pub fn set_usage_type(self, input: Option<UsageLimitUsageType>) -> Self
The type of Amazon Redshift Serverless usage to create a usage limit for.
Sourcepub fn get_usage_type(&self) -> &Option<UsageLimitUsageType>
pub fn get_usage_type(&self) -> &Option<UsageLimitUsageType>
The type of Amazon Redshift Serverless usage to create a usage limit for.
Sourcepub fn amount(self, input: i64) -> Self
pub fn amount(self, input: i64) -> Self
The limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
This field is required.Sourcepub fn set_amount(self, input: Option<i64>) -> Self
pub fn set_amount(self, input: Option<i64>) -> Self
The limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
Sourcepub fn get_amount(&self) -> &Option<i64>
pub fn get_amount(&self) -> &Option<i64>
The limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
Sourcepub fn period(self, input: UsageLimitPeriod) -> Self
pub fn period(self, input: UsageLimitPeriod) -> Self
The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.
Sourcepub fn set_period(self, input: Option<UsageLimitPeriod>) -> Self
pub fn set_period(self, input: Option<UsageLimitPeriod>) -> Self
The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.
Sourcepub fn get_period(&self) -> &Option<UsageLimitPeriod>
pub fn get_period(&self) -> &Option<UsageLimitPeriod>
The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.
Sourcepub fn breach_action(self, input: UsageLimitBreachAction) -> Self
pub fn breach_action(self, input: UsageLimitBreachAction) -> Self
The action that Amazon Redshift Serverless takes when the limit is reached. The default is log.
Sourcepub fn set_breach_action(self, input: Option<UsageLimitBreachAction>) -> Self
pub fn set_breach_action(self, input: Option<UsageLimitBreachAction>) -> Self
The action that Amazon Redshift Serverless takes when the limit is reached. The default is log.
Sourcepub fn get_breach_action(&self) -> &Option<UsageLimitBreachAction>
pub fn get_breach_action(&self) -> &Option<UsageLimitBreachAction>
The action that Amazon Redshift Serverless takes when the limit is reached. The default is log.
Sourcepub fn build(self) -> Result<CreateUsageLimitInput, BuildError>
pub fn build(self) -> Result<CreateUsageLimitInput, BuildError>
Consumes the builder and constructs a CreateUsageLimitInput.
Sourceimpl CreateUsageLimitInputBuilder
impl CreateUsageLimitInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<CreateUsageLimitOutput, SdkError<CreateUsageLimitError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<CreateUsageLimitOutput, SdkError<CreateUsageLimitError, HttpResponse>>
Sends a request with this input using the given client.