CreateWorkgroupInputBuilder

Struct CreateWorkgroupInputBuilder 

#[non_exhaustive]
pub struct CreateWorkgroupInputBuilder { /* private fields */ }
A builder for CreateWorkgroupInput.

Implementations

Source

impl CreateWorkgroupInputBuilder

pub fn workgroup_name(self, input: impl Into<String>) -> Self

The name of the created workgroup.

This field is required.
pub fn set_workgroup_name(self, input: Option<String>) -> Self

The name of the created workgroup.

pub fn get_workgroup_name(&self) -> &Option<String>

The name of the created workgroup.

pub fn namespace_name(self, input: impl Into<String>) -> Self

The name of the namespace to associate with the workgroup.

This field is required.
pub fn set_namespace_name(self, input: Option<String>) -> Self

The name of the namespace to associate with the workgroup.

pub fn get_namespace_name(&self) -> &Option<String>

The name of the namespace to associate with the workgroup.

pub fn base_capacity(self, input: i32) -> Self

The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).

pub fn set_base_capacity(self, input: Option<i32>) -> Self

The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).

pub fn get_base_capacity(&self) -> &Option<i32>

The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).

pub fn enhanced_vpc_routing(self, input: bool) -> Self

The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.

pub fn set_enhanced_vpc_routing(self, input: Option<bool>) -> Self

The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.

pub fn get_enhanced_vpc_routing(&self) -> &Option<bool>

The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.

pub fn config_parameters(self, input: ConfigParameter) -> Self

Appends an item to config_parameters.

To override the contents of this collection use set_config_parameters.

An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.

pub fn set_config_parameters(self, input: Option<Vec<ConfigParameter>>) -> Self

An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.

pub fn get_config_parameters(&self) -> &Option<Vec<ConfigParameter>>

An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.

pub fn security_group_ids(self, input: impl Into<String>) -> Self

Appends an item to security_group_ids.

To override the contents of this collection use set_security_group_ids.

An array of security group IDs to associate with the workgroup.

pub fn set_security_group_ids(self, input: Option<Vec<String>>) -> Self

An array of security group IDs to associate with the workgroup.

pub fn get_security_group_ids(&self) -> &Option<Vec<String>>

An array of security group IDs to associate with the workgroup.

pub fn subnet_ids(self, input: impl Into<String>) -> Self

Appends an item to subnet_ids.

To override the contents of this collection use set_subnet_ids.

An array of VPC subnet IDs to associate with the workgroup.

pub fn set_subnet_ids(self, input: Option<Vec<String>>) -> Self

An array of VPC subnet IDs to associate with the workgroup.

pub fn get_subnet_ids(&self) -> &Option<Vec<String>>

An array of VPC subnet IDs to associate with the workgroup.

pub fn publicly_accessible(self, input: bool) -> Self

A value that specifies whether the workgroup can be accessed from a public network.

pub fn set_publicly_accessible(self, input: Option<bool>) -> Self

A value that specifies whether the workgroup can be accessed from a public network.

pub fn get_publicly_accessible(&self) -> &Option<bool>

A value that specifies whether the workgroup can be accessed from a public network.

pub fn tags(self, input: Tag) -> Self

Appends an item to tags.

To override the contents of this collection use set_tags.

A array of tag instances.

pub fn set_tags(self, input: Option<Vec<Tag>>) -> Self

A array of tag instances.

pub fn get_tags(&self) -> &Option<Vec<Tag>>

A array of tag instances.

pub fn port(self, input: i32) -> Self

The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.

pub fn set_port(self, input: Option<i32>) -> Self

The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.

pub fn get_port(&self) -> &Option<i32>

The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.

pub fn max_capacity(self, input: i32) -> Self

The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.

pub fn set_max_capacity(self, input: Option<i32>) -> Self

The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.

pub fn get_max_capacity(&self) -> &Option<i32>

The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.

pub fn price_performance_target(self, input: PerformanceTarget) -> Self

An object that represents the price performance target settings for the workgroup.

pub fn set_price_performance_target( self, input: Option<PerformanceTarget>, ) -> Self

An object that represents the price performance target settings for the workgroup.

pub fn get_price_performance_target(&self) -> &Option<PerformanceTarget>

An object that represents the price performance target settings for the workgroup.

pub fn ip_address_type(self, input: impl Into<String>) -> Self

The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.

pub fn set_ip_address_type(self, input: Option<String>) -> Self

The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.

pub fn get_ip_address_type(&self) -> &Option<String>

The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.

pub fn track_name(self, input: impl Into<String>) -> Self

An optional parameter for the name of the track for the workgroup. If you don't provide a track name, the workgroup is assigned to the current track.

pub fn set_track_name(self, input: Option<String>) -> Self

An optional parameter for the name of the track for the workgroup. If you don't provide a track name, the workgroup is assigned to the current track.

pub fn get_track_name(&self) -> &Option<String>

An optional parameter for the name of the track for the workgroup. If you don't provide a track name, the workgroup is assigned to the current track.

pub fn extra_compute_for_automatic_optimization(self, input: bool) -> Self

If true, allocates additional compute resources for running automatic optimization operations.

Default: false

pub fn set_extra_compute_for_automatic_optimization( self, input: Option<bool>, ) -> Self

If true, allocates additional compute resources for running automatic optimization operations.

Default: false

pub fn get_extra_compute_for_automatic_optimization(&self) -> &Option<bool>

If true, allocates additional compute resources for running automatic optimization operations.

Default: false

pub fn build(self) -> Result<CreateWorkgroupInput, BuildError>

Consumes the builder and constructs a CreateWorkgroupInput.

Source

impl CreateWorkgroupInputBuilder

pub async fn send_with( self, client: &Client, ) -> Result<CreateWorkgroupOutput, SdkError<CreateWorkgroupError, HttpResponse>>

Sends a request with this input using the given client.