CreateWorkgroupInput

Struct CreateWorkgroupInput 

#[non_exhaustive]
pub struct CreateWorkgroupInput {
Show 15 fields pub workgroup_name: Option<String>, pub namespace_name: Option<String>, pub base_capacity: Option<i32>, pub enhanced_vpc_routing: Option<bool>, pub config_parameters: Option<Vec<ConfigParameter>>, pub security_group_ids: Option<Vec<String>>, pub subnet_ids: Option<Vec<String>>, pub publicly_accessible: Option<bool>, pub tags: Option<Vec<Tag>>, pub port: Option<i32>, pub max_capacity: Option<i32>, pub price_performance_target: Option<PerformanceTarget>, pub ip_address_type: Option<String>, pub track_name: Option<String>, pub extra_compute_for_automatic_optimization: Option<bool>,
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
workgroup_name: Option<String>

The name of the created workgroup.

namespace_name: Option<String>

The name of the namespace to associate with the workgroup.

base_capacity: Option<i32>

The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).

enhanced_vpc_routing: Option<bool>

The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.

config_parameters: Option<Vec<ConfigParameter>>

An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.

security_group_ids: Option<Vec<String>>

An array of security group IDs to associate with the workgroup.

subnet_ids: Option<Vec<String>>

An array of VPC subnet IDs to associate with the workgroup.

publicly_accessible: Option<bool>

A value that specifies whether the workgroup can be accessed from a public network.

tags: Option<Vec<Tag>>

A array of tag instances.

port: Option<i32>

The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.

max_capacity: Option<i32>

The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.

price_performance_target: Option<PerformanceTarget>

An object that represents the price performance target settings for the workgroup.

ip_address_type: Option<String>

The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.

track_name: Option<String>

An optional parameter for the name of the track for the workgroup. If you don't provide a track name, the workgroup is assigned to the current track.

extra_compute_for_automatic_optimization: Option<bool>

If true, allocates additional compute resources for running automatic optimization operations.

Default: false

Implementations

Source

impl CreateWorkgroupInput

pub fn workgroup_name(&self) -> Option<&str>

The name of the created workgroup.

pub fn namespace_name(&self) -> Option<&str>

The name of the namespace to associate with the workgroup.

pub fn base_capacity(&self) -> Option<i32>

The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).

pub fn enhanced_vpc_routing(&self) -> Option<bool>

The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.

pub fn config_parameters(&self) -> &[ConfigParameter]

An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .config_parameters.is_none().

pub fn security_group_ids(&self) -> &[String]

An array of security group IDs to associate with the workgroup.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_ids.is_none().

pub fn subnet_ids(&self) -> &[String]

An array of VPC subnet IDs to associate with the workgroup.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().

pub fn publicly_accessible(&self) -> Option<bool>

A value that specifies whether the workgroup can be accessed from a public network.

pub fn tags(&self) -> &[Tag]

A array of tag instances.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().

pub fn port(&self) -> Option<i32>

The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.

pub fn max_capacity(&self) -> Option<i32>

The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.

pub fn price_performance_target(&self) -> Option<&PerformanceTarget>

An object that represents the price performance target settings for the workgroup.

pub fn ip_address_type(&self) -> Option<&str>

The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.

pub fn track_name(&self) -> Option<&str>

An optional parameter for the name of the track for the workgroup. If you don't provide a track name, the workgroup is assigned to the current track.

pub fn extra_compute_for_automatic_optimization(&self) -> Option<bool>

If true, allocates additional compute resources for running automatic optimization operations.

Default: false

Source

impl CreateWorkgroupInput

pub fn builder() -> CreateWorkgroupInputBuilder

Creates a new builder-style object to manufacture CreateWorkgroupInput.