#[non_exhaustive]pub struct GetCredentialsInput {
pub db_name: Option<String>,
pub duration_seconds: Option<i32>,
pub workgroup_name: Option<String>,
pub custom_domain_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.db_name: Option<String>The name of the database to get temporary authorization to log on to.
Constraints:
-
Must be 1 to 64 alphanumeric characters or hyphens.
-
Must contain only uppercase or lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.
-
The first character must be a letter.
-
Must not contain a colon ( : ) or slash ( / ).
-
Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide
duration_seconds: Option<i32>The number of seconds until the returned temporary password expires. The minimum is 900 seconds, and the maximum is 3600 seconds.
workgroup_name: Option<String>The name of the workgroup associated with the database.
custom_domain_name: Option<String>The custom domain name associated with the workgroup. The custom domain name or the workgroup name must be included in the request.
Implementations
Sourceimpl GetCredentialsInput
impl GetCredentialsInput
Sourcepub fn db_name(&self) -> Option<&str>
pub fn db_name(&self) -> Option<&str>
The name of the database to get temporary authorization to log on to.
Constraints:
-
Must be 1 to 64 alphanumeric characters or hyphens.
-
Must contain only uppercase or lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.
-
The first character must be a letter.
-
Must not contain a colon ( : ) or slash ( / ).
-
Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide
Sourcepub fn duration_seconds(&self) -> Option<i32>
pub fn duration_seconds(&self) -> Option<i32>
The number of seconds until the returned temporary password expires. The minimum is 900 seconds, and the maximum is 3600 seconds.
Sourcepub fn workgroup_name(&self) -> Option<&str>
pub fn workgroup_name(&self) -> Option<&str>
The name of the workgroup associated with the database.
Sourcepub fn custom_domain_name(&self) -> Option<&str>
pub fn custom_domain_name(&self) -> Option<&str>
The custom domain name associated with the workgroup. The custom domain name or the workgroup name must be included in the request.
Sourceimpl GetCredentialsInput
impl GetCredentialsInput
Sourcepub fn builder() -> GetCredentialsInputBuilder
pub fn builder() -> GetCredentialsInputBuilder
Creates a new builder-style object to manufacture GetCredentialsInput.