#[non_exhaustive]pub struct ListWorkgroupsInputBuilder { /* private fields */ }Expand description
A builder for ListWorkgroupsInput.
Implementations
Sourceimpl ListWorkgroupsInputBuilder
impl ListWorkgroupsInputBuilder
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
If your initial ListWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListNamespaces operations, which returns results in the next page.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
If your initial ListWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListNamespaces operations, which returns results in the next page.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
If your initial ListWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListNamespaces operations, which returns results in the next page.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
Sourcepub fn owner_account(self, input: impl Into<String>) -> Self
pub fn owner_account(self, input: impl Into<String>) -> Self
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn set_owner_account(self, input: Option<String>) -> Self
pub fn set_owner_account(self, input: Option<String>) -> Self
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn get_owner_account(&self) -> &Option<String>
pub fn get_owner_account(&self) -> &Option<String>
The owner Amazon Web Services account for the Amazon Redshift Serverless workgroup.
Sourcepub fn build(self) -> Result<ListWorkgroupsInput, BuildError>
pub fn build(self) -> Result<ListWorkgroupsInput, BuildError>
Consumes the builder and constructs a ListWorkgroupsInput.
Sourceimpl ListWorkgroupsInputBuilder
impl ListWorkgroupsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<ListWorkgroupsOutput, SdkError<ListWorkgroupsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<ListWorkgroupsOutput, SdkError<ListWorkgroupsError, HttpResponse>>
Sends a request with this input using the given client.