#[non_exhaustive]pub struct UpdateUsageLimitInput {
pub usage_limit_id: Option<String>,
pub amount: Option<i64>,
pub breach_action: Option<UsageLimitBreachAction>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.usage_limit_id: Option<String>The identifier of the usage limit to update.
amount: Option<i64>The new limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
breach_action: Option<UsageLimitBreachAction>The new action that Amazon Redshift Serverless takes when the limit is reached.
Implementations
Sourceimpl UpdateUsageLimitInput
impl UpdateUsageLimitInput
Sourcepub fn usage_limit_id(&self) -> Option<&str>
pub fn usage_limit_id(&self) -> Option<&str>
The identifier of the usage limit to update.
Sourcepub fn amount(&self) -> Option<i64>
pub fn amount(&self) -> Option<i64>
The new limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
Sourcepub fn breach_action(&self) -> Option<&UsageLimitBreachAction>
pub fn breach_action(&self) -> Option<&UsageLimitBreachAction>
The new action that Amazon Redshift Serverless takes when the limit is reached.
Sourceimpl UpdateUsageLimitInput
impl UpdateUsageLimitInput
Sourcepub fn builder() -> UpdateUsageLimitInputBuilder
pub fn builder() -> UpdateUsageLimitInputBuilder
Creates a new builder-style object to manufacture UpdateUsageLimitInput.