Struct aws_sdk_redshiftserverless::Client
source · pub struct Client { /* private fields */ }Expand description
Client for Redshift Serverless
Client for invoking operations on Redshift Serverless. Each operation on Redshift Serverless is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_redshiftserverless::Client::new(&config);Occasionally, SDKs may have additional service-specific that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Config struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_redshiftserverless::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the DeleteResourcePolicy operation has
a Client::delete_resource_policy, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.delete_resource_policy()
.resource_arn("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
sourceimpl Client
impl Client
sourcepub fn convert_recovery_point_to_snapshot(
&self
) -> ConvertRecoveryPointToSnapshotFluentBuilder
pub fn convert_recovery_point_to_snapshot( &self ) -> ConvertRecoveryPointToSnapshotFluentBuilder
Constructs a fluent builder for the ConvertRecoveryPointToSnapshot operation.
- The fluent builder is configurable:
recovery_point_id(impl Into<String>)/set_recovery_point_id(Option<String>):The unique identifier of the recovery point.
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot.
retention_period(i32)/set_retention_period(Option<i32>):How long to retain the snapshot.
tags(Tag)/set_tags(Option<Vec<Tag>>):An array of Tag objects to associate with the created snapshot.
- On success, responds with
ConvertRecoveryPointToSnapshotOutputwith field(s):snapshot(Option<Snapshot>):The snapshot converted from the recovery point.
- On failure, responds with
SdkError<ConvertRecoveryPointToSnapshotError>
sourceimpl Client
impl Client
sourcepub fn create_endpoint_access(&self) -> CreateEndpointAccessFluentBuilder
pub fn create_endpoint_access(&self) -> CreateEndpointAccessFluentBuilder
Constructs a fluent builder for the CreateEndpointAccess operation.
- The fluent builder is configurable:
endpoint_name(impl Into<String>)/set_endpoint_name(Option<String>):The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can’t contain two consecutive hyphens or end with a hyphen.
subnet_ids(impl Into<String>)/set_subnet_ids(Option<Vec<String>>):The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup to associate with the VPC endpoint.
vpc_security_group_ids(impl Into<String>)/set_vpc_security_group_ids(Option<Vec<String>>):The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
- On success, responds with
CreateEndpointAccessOutputwith field(s):endpoint(Option<EndpointAccess>):The created VPC endpoint.
- On failure, responds with
SdkError<CreateEndpointAccessError>
sourceimpl Client
impl Client
sourcepub fn create_namespace(&self) -> CreateNamespaceFluentBuilder
pub fn create_namespace(&self) -> CreateNamespaceFluentBuilder
Constructs a fluent builder for the CreateNamespace operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace.
admin_username(impl Into<String>)/set_admin_username(Option<String>):The username of the administrator for the first database created in the namespace.
admin_user_password(impl Into<String>)/set_admin_user_password(Option<String>):The password of the administrator for the first database created in the namespace.
You can’t use
adminUserPasswordifmanageAdminPasswordis true.db_name(impl Into<String>)/set_db_name(Option<String>):The name of the first database created in the namespace.
kms_key_id(impl Into<String>)/set_kms_key_id(Option<String>):The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
default_iam_role_arn(impl Into<String>)/set_default_iam_role_arn(Option<String>):The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
iam_roles(impl Into<String>)/set_iam_roles(Option<Vec<String>>):A list of IAM roles to associate with the namespace.
log_exports(LogExport)/set_log_exports(Option<Vec<LogExport>>):The types of logs the namespace can export. Available export types are
userlog,connectionlog, anduseractivitylog.tags(Tag)/set_tags(Option<Vec<Tag>>):A list of tag instances.
manage_admin_password(bool)/set_manage_admin_password(Option<bool>):If
true, Amazon Redshift uses Secrets Manager to manage the namespace’s admin credentials. You can’t useadminUserPasswordifmanageAdminPasswordis true. IfmanageAdminPasswordis false or not set, Amazon Redshift usesadminUserPasswordfor the admin user account’s password.admin_password_secret_kms_key_id(impl Into<String>)/set_admin_password_secret_kms_key_id(Option<String>):The ID of the Key Management Service (KMS) key used to encrypt and store the namespace’s admin credentials secret. You can only use this parameter if
manageAdminPasswordis true.
- On success, responds with
CreateNamespaceOutputwith field(s):namespace(Option<Namespace>):The created namespace object.
- On failure, responds with
SdkError<CreateNamespaceError>
sourceimpl Client
impl Client
sourcepub fn create_snapshot(&self) -> CreateSnapshotFluentBuilder
pub fn create_snapshot(&self) -> CreateSnapshotFluentBuilder
Constructs a fluent builder for the CreateSnapshot operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The namespace to create a snapshot for.
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot.
retention_period(i32)/set_retention_period(Option<i32>):How long to retain the created snapshot.
tags(Tag)/set_tags(Option<Vec<Tag>>):An array of Tag objects to associate with the snapshot.
- On success, responds with
CreateSnapshotOutputwith field(s):snapshot(Option<Snapshot>):The created snapshot object.
- On failure, responds with
SdkError<CreateSnapshotError>
sourceimpl Client
impl Client
sourcepub fn create_usage_limit(&self) -> CreateUsageLimitFluentBuilder
pub fn create_usage_limit(&self) -> CreateUsageLimitFluentBuilder
Constructs a fluent builder for the CreateUsageLimit operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the Amazon Redshift Serverless resource to create the usage limit for.
usage_type(UsageLimitUsageType)/set_usage_type(Option<UsageLimitUsageType>):The type of Amazon Redshift Serverless usage to create a usage limit for.
amount(i64)/set_amount(Option<i64>):The limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
period(UsageLimitPeriod)/set_period(Option<UsageLimitPeriod>):The time period that the amount applies to. A weekly period begins on Sunday. The default is monthly.
breach_action(UsageLimitBreachAction)/set_breach_action(Option<UsageLimitBreachAction>):The action that Amazon Redshift Serverless takes when the limit is reached. The default is log.
- On success, responds with
CreateUsageLimitOutputwith field(s):usage_limit(Option<UsageLimit>):The returned usage limit object.
- On failure, responds with
SdkError<CreateUsageLimitError>
sourceimpl Client
impl Client
sourcepub fn create_workgroup(&self) -> CreateWorkgroupFluentBuilder
pub fn create_workgroup(&self) -> CreateWorkgroupFluentBuilder
Constructs a fluent builder for the CreateWorkgroup operation.
- The fluent builder is configurable:
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the created workgroup.
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to associate with the workgroup.
base_capacity(i32)/set_base_capacity(Option<i32>):The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
enhanced_vpc_routing(bool)/set_enhanced_vpc_routing(Option<bool>):The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.
config_parameters(ConfigParameter)/set_config_parameters(Option<Vec<ConfigParameter>>):An array of parameters to set for advanced control over a database. The options are
auto_mv,datestyle,enable_case_sensitivity_identifier,enable_user_activity_logging,query_group,search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.security_group_ids(impl Into<String>)/set_security_group_ids(Option<Vec<String>>):An array of security group IDs to associate with the workgroup.
subnet_ids(impl Into<String>)/set_subnet_ids(Option<Vec<String>>):An array of VPC subnet IDs to associate with the workgroup.
publicly_accessible(bool)/set_publicly_accessible(Option<bool>):A value that specifies whether the workgroup can be accessed from a public network.
tags(Tag)/set_tags(Option<Vec<Tag>>):A array of tag instances.
port(i32)/set_port(Option<i32>):The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
- On success, responds with
CreateWorkgroupOutputwith field(s):workgroup(Option<Workgroup>):The created workgroup object.
- On failure, responds with
SdkError<CreateWorkgroupError>
sourceimpl Client
impl Client
sourcepub fn delete_endpoint_access(&self) -> DeleteEndpointAccessFluentBuilder
pub fn delete_endpoint_access(&self) -> DeleteEndpointAccessFluentBuilder
Constructs a fluent builder for the DeleteEndpointAccess operation.
- The fluent builder is configurable:
endpoint_name(impl Into<String>)/set_endpoint_name(Option<String>):The name of the VPC endpoint to delete.
- On success, responds with
DeleteEndpointAccessOutputwith field(s):endpoint(Option<EndpointAccess>):The deleted VPC endpoint.
- On failure, responds with
SdkError<DeleteEndpointAccessError>
sourceimpl Client
impl Client
sourcepub fn delete_namespace(&self) -> DeleteNamespaceFluentBuilder
pub fn delete_namespace(&self) -> DeleteNamespaceFluentBuilder
Constructs a fluent builder for the DeleteNamespace operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to delete.
final_snapshot_name(impl Into<String>)/set_final_snapshot_name(Option<String>):The name of the snapshot to be created before the namespace is deleted.
final_snapshot_retention_period(i32)/set_final_snapshot_retention_period(Option<i32>):How long to retain the final snapshot.
- On success, responds with
DeleteNamespaceOutputwith field(s):namespace(Option<Namespace>):The deleted namespace object.
- On failure, responds with
SdkError<DeleteNamespaceError>
sourceimpl Client
impl Client
sourcepub fn delete_resource_policy(&self) -> DeleteResourcePolicyFluentBuilder
pub fn delete_resource_policy(&self) -> DeleteResourcePolicyFluentBuilder
Constructs a fluent builder for the DeleteResourcePolicy operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the policy to delete.
- On success, responds with
DeleteResourcePolicyOutput - On failure, responds with
SdkError<DeleteResourcePolicyError>
sourceimpl Client
impl Client
sourcepub fn delete_snapshot(&self) -> DeleteSnapshotFluentBuilder
pub fn delete_snapshot(&self) -> DeleteSnapshotFluentBuilder
Constructs a fluent builder for the DeleteSnapshot operation.
- The fluent builder is configurable:
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot to be deleted.
- On success, responds with
DeleteSnapshotOutputwith field(s):snapshot(Option<Snapshot>):The deleted snapshot object.
- On failure, responds with
SdkError<DeleteSnapshotError>
sourceimpl Client
impl Client
sourcepub fn delete_usage_limit(&self) -> DeleteUsageLimitFluentBuilder
pub fn delete_usage_limit(&self) -> DeleteUsageLimitFluentBuilder
Constructs a fluent builder for the DeleteUsageLimit operation.
- The fluent builder is configurable:
usage_limit_id(impl Into<String>)/set_usage_limit_id(Option<String>):The unique identifier of the usage limit to delete.
- On success, responds with
DeleteUsageLimitOutputwith field(s):usage_limit(Option<UsageLimit>):The deleted usage limit object.
- On failure, responds with
SdkError<DeleteUsageLimitError>
sourceimpl Client
impl Client
sourcepub fn delete_workgroup(&self) -> DeleteWorkgroupFluentBuilder
pub fn delete_workgroup(&self) -> DeleteWorkgroupFluentBuilder
Constructs a fluent builder for the DeleteWorkgroup operation.
- The fluent builder is configurable:
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup to be deleted.
- On success, responds with
DeleteWorkgroupOutputwith field(s):workgroup(Option<Workgroup>):The deleted workgroup object.
- On failure, responds with
SdkError<DeleteWorkgroupError>
sourceimpl Client
impl Client
sourcepub fn get_credentials(&self) -> GetCredentialsFluentBuilder
pub fn get_credentials(&self) -> GetCredentialsFluentBuilder
Constructs a fluent builder for the GetCredentials operation.
- The fluent builder is configurable:
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup associated with the database.
db_name(impl Into<String>)/set_db_name(Option<String>):The name of the database to get temporary authorization to log on to.
Constraints:
-
Must be 1 to 64 alphanumeric characters or hyphens.
-
Must contain only uppercase or lowercase letters, numbers, underscore, plus sign, period (dot), at symbol (@), or hyphen.
-
The first character must be a letter.
-
Must not contain a colon ( : ) or slash ( / ).
-
Cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide
-
duration_seconds(i32)/set_duration_seconds(Option<i32>):The number of seconds until the returned temporary password expires. The minimum is 900 seconds, and the maximum is 3600 seconds.
- On success, responds with
GetCredentialsOutputwith field(s):db_user(Option<String>):A database user name that is authorized to log on to the database
DbNameusing the passwordDbPassword. If the specifiedDbUserexists in the database, the new user name has the same database privileges as the the user named inDbUser. By default, the user is added to PUBLIC.db_password(Option<String>):A temporary password that authorizes the user name returned by
DbUserto log on to the databaseDbName.expiration(Option<DateTime>):The date and time the password in
DbPasswordexpires.next_refresh_time(Option<DateTime>):The date and time of when the
DbUserandDbPasswordauthorization refreshes.
- On failure, responds with
SdkError<GetCredentialsError>
sourceimpl Client
impl Client
sourcepub fn get_endpoint_access(&self) -> GetEndpointAccessFluentBuilder
pub fn get_endpoint_access(&self) -> GetEndpointAccessFluentBuilder
Constructs a fluent builder for the GetEndpointAccess operation.
- The fluent builder is configurable:
endpoint_name(impl Into<String>)/set_endpoint_name(Option<String>):The name of the VPC endpoint to return information for.
- On success, responds with
GetEndpointAccessOutputwith field(s):endpoint(Option<EndpointAccess>):The returned VPC endpoint.
- On failure, responds with
SdkError<GetEndpointAccessError>
sourceimpl Client
impl Client
sourcepub fn get_namespace(&self) -> GetNamespaceFluentBuilder
pub fn get_namespace(&self) -> GetNamespaceFluentBuilder
Constructs a fluent builder for the GetNamespace operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to retrieve information for.
- On success, responds with
GetNamespaceOutputwith field(s):namespace(Option<Namespace>):The returned namespace object.
- On failure, responds with
SdkError<GetNamespaceError>
sourceimpl Client
impl Client
sourcepub fn get_recovery_point(&self) -> GetRecoveryPointFluentBuilder
pub fn get_recovery_point(&self) -> GetRecoveryPointFluentBuilder
Constructs a fluent builder for the GetRecoveryPoint operation.
- The fluent builder is configurable:
recovery_point_id(impl Into<String>)/set_recovery_point_id(Option<String>):The unique identifier of the recovery point to return information for.
- On success, responds with
GetRecoveryPointOutputwith field(s):recovery_point(Option<RecoveryPoint>):The returned recovery point object.
- On failure, responds with
SdkError<GetRecoveryPointError>
sourceimpl Client
impl Client
sourcepub fn get_resource_policy(&self) -> GetResourcePolicyFluentBuilder
pub fn get_resource_policy(&self) -> GetResourcePolicyFluentBuilder
Constructs a fluent builder for the GetResourcePolicy operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the resource to return.
- On success, responds with
GetResourcePolicyOutputwith field(s):resource_policy(Option<ResourcePolicy>):The returned resource policy.
- On failure, responds with
SdkError<GetResourcePolicyError>
sourceimpl Client
impl Client
sourcepub fn get_snapshot(&self) -> GetSnapshotFluentBuilder
pub fn get_snapshot(&self) -> GetSnapshotFluentBuilder
Constructs a fluent builder for the GetSnapshot operation.
- The fluent builder is configurable:
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot to return.
owner_account(impl Into<String>)/set_owner_account(Option<String>):The owner Amazon Web Services account of a snapshot shared with another user.
snapshot_arn(impl Into<String>)/set_snapshot_arn(Option<String>):The Amazon Resource Name (ARN) of the snapshot to return.
- On success, responds with
GetSnapshotOutputwith field(s):snapshot(Option<Snapshot>):The returned snapshot object.
- On failure, responds with
SdkError<GetSnapshotError>
sourceimpl Client
impl Client
sourcepub fn get_table_restore_status(&self) -> GetTableRestoreStatusFluentBuilder
pub fn get_table_restore_status(&self) -> GetTableRestoreStatusFluentBuilder
Constructs a fluent builder for the GetTableRestoreStatus operation.
- The fluent builder is configurable:
table_restore_request_id(impl Into<String>)/set_table_restore_request_id(Option<String>):The ID of the
RestoreTableFromSnapshotrequest to return status for.
- On success, responds with
GetTableRestoreStatusOutputwith field(s):table_restore_status(Option<TableRestoreStatus>):The returned
TableRestoreStatusobject that contains information about the status of yourRestoreTableFromSnapshotrequest.
- On failure, responds with
SdkError<GetTableRestoreStatusError>
sourceimpl Client
impl Client
sourcepub fn get_usage_limit(&self) -> GetUsageLimitFluentBuilder
pub fn get_usage_limit(&self) -> GetUsageLimitFluentBuilder
Constructs a fluent builder for the GetUsageLimit operation.
- The fluent builder is configurable:
usage_limit_id(impl Into<String>)/set_usage_limit_id(Option<String>):The unique identifier of the usage limit to return information for.
- On success, responds with
GetUsageLimitOutputwith field(s):usage_limit(Option<UsageLimit>):The returned usage limit object.
- On failure, responds with
SdkError<GetUsageLimitError>
sourceimpl Client
impl Client
sourcepub fn get_workgroup(&self) -> GetWorkgroupFluentBuilder
pub fn get_workgroup(&self) -> GetWorkgroupFluentBuilder
Constructs a fluent builder for the GetWorkgroup operation.
- The fluent builder is configurable:
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup to return information for.
- On success, responds with
GetWorkgroupOutputwith field(s):workgroup(Option<Workgroup>):The returned workgroup object.
- On failure, responds with
SdkError<GetWorkgroupError>
sourceimpl Client
impl Client
sourcepub fn list_endpoint_access(&self) -> ListEndpointAccessFluentBuilder
pub fn list_endpoint_access(&self) -> ListEndpointAccessFluentBuilder
Constructs a fluent builder for the ListEndpointAccess operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial
ListEndpointAccessoperation returns anextToken, you can include the returnednextTokenin followingListEndpointAccessoperations, which returns results in the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento display the next page of results.workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup associated with the VPC endpoint to return.
vpc_id(impl Into<String>)/set_vpc_id(Option<String>):The unique identifier of the virtual private cloud with access to Amazon Redshift Serverless.
- On success, responds with
ListEndpointAccessOutputwith field(s):next_token(Option<String>):When
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.endpoints(Option<Vec<EndpointAccess>>):The returned VPC endpoints.
- On failure, responds with
SdkError<ListEndpointAccessError>
sourceimpl Client
impl Client
sourcepub fn list_namespaces(&self) -> ListNamespacesFluentBuilder
pub fn list_namespaces(&self) -> ListNamespacesFluentBuilder
Constructs a fluent builder for the ListNamespaces operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial
ListNamespacesoperation returns anextToken, you can include the returnednextTokenin followingListNamespacesoperations, which returns results in the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento display the next page of results.
- On success, responds with
ListNamespacesOutputwith field(s):next_token(Option<String>):When
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.namespaces(Option<Vec<Namespace>>):The list of returned namespaces.
- On failure, responds with
SdkError<ListNamespacesError>
sourceimpl Client
impl Client
sourcepub fn list_recovery_points(&self) -> ListRecoveryPointsFluentBuilder
pub fn list_recovery_points(&self) -> ListRecoveryPointsFluentBuilder
Constructs a fluent builder for the ListRecoveryPoints operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial
ListRecoveryPointsoperation returns anextToken, you can include the returnednextTokenin followingListRecoveryPointsoperations, which returns results in the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento display the next page of results.start_time(DateTime)/set_start_time(Option<DateTime>):The time when the recovery point’s creation was initiated.
end_time(DateTime)/set_end_time(Option<DateTime>):The time when creation of the recovery point finished.
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to list recovery points for.
namespace_arn(impl Into<String>)/set_namespace_arn(Option<String>):The Amazon Resource Name (ARN) of the namespace from which to list recovery points.
- On success, responds with
ListRecoveryPointsOutputwith field(s):recovery_points(Option<Vec<RecoveryPoint>>):The returned recovery point objects.
next_token(Option<String>):If
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.
- On failure, responds with
SdkError<ListRecoveryPointsError>
sourceimpl Client
impl Client
sourcepub fn list_snapshots(&self) -> ListSnapshotsFluentBuilder
pub fn list_snapshots(&self) -> ListSnapshotsFluentBuilder
Constructs a fluent builder for the ListSnapshots operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento display the next page of results.namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The namespace from which to list all snapshots.
namespace_arn(impl Into<String>)/set_namespace_arn(Option<String>):The Amazon Resource Name (ARN) of the namespace from which to list all snapshots.
owner_account(impl Into<String>)/set_owner_account(Option<String>):The owner Amazon Web Services account of the snapshot.
start_time(DateTime)/set_start_time(Option<DateTime>):The time when the creation of the snapshot was initiated.
end_time(DateTime)/set_end_time(Option<DateTime>):The timestamp showing when the snapshot creation finished.
- On success, responds with
ListSnapshotsOutputwith field(s):next_token(Option<String>):If
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.snapshots(Option<Vec<Snapshot>>):All of the returned snapshot objects.
- On failure, responds with
SdkError<ListSnapshotsError>
sourceimpl Client
impl Client
sourcepub fn list_table_restore_status(&self) -> ListTableRestoreStatusFluentBuilder
pub fn list_table_restore_status(&self) -> ListTableRestoreStatusFluentBuilder
Constructs a fluent builder for the ListTableRestoreStatus operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial
ListTableRestoreStatusoperation returns a nextToken, you can include the returnednextTokenin followingListTableRestoreStatusoperations. This will return results on the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results.
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The namespace from which to list all of the statuses of
RestoreTableFromSnapshotoperations .workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The workgroup from which to list all of the statuses of
RestoreTableFromSnapshotoperations.
- On success, responds with
ListTableRestoreStatusOutputwith field(s):next_token(Option<String>):If your initial
ListTableRestoreStatusoperation returns anextToken, you can include the returnednextTokenin followingListTableRestoreStatusoperations. This will returns results on the next page.table_restore_statuses(Option<Vec<TableRestoreStatus>>):The array of returned
TableRestoreStatusobjects.
- On failure, responds with
SdkError<ListTableRestoreStatusError>
sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the resource to list tags for.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<Vec<Tag>>):A map of the key-value pairs assigned to the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
sourceimpl Client
impl Client
sourcepub fn list_usage_limits(&self) -> ListUsageLimitsFluentBuilder
pub fn list_usage_limits(&self) -> ListUsageLimitsFluentBuilder
Constructs a fluent builder for the ListUsageLimits operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) associated with the resource whose usage limits you want to list.
usage_type(UsageLimitUsageType)/set_usage_type(Option<UsageLimitUsageType>):The Amazon Redshift Serverless feature whose limits you want to see.
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial
ListUsageLimitsoperation returns anextToken, you can include the returnednextTokenin followingListUsageLimitsoperations, which returns results in the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento get the next page of results. The default is 100.
- On success, responds with
ListUsageLimitsOutputwith field(s):usage_limits(Option<Vec<UsageLimit>>):An array of returned usage limit objects.
next_token(Option<String>):When
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. Make the call again using the returned token to retrieve the next page.
- On failure, responds with
SdkError<ListUsageLimitsError>
sourceimpl Client
impl Client
sourcepub fn list_workgroups(&self) -> ListWorkgroupsFluentBuilder
pub fn list_workgroups(&self) -> ListWorkgroupsFluentBuilder
Constructs a fluent builder for the ListWorkgroups operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
next_token(impl Into<String>)/set_next_token(Option<String>):If your initial ListWorkgroups operation returns a
nextToken, you can include the returnednextTokenin following ListNamespaces operations, which returns results in the next page.max_results(i32)/set_max_results(Option<i32>):An optional parameter that specifies the maximum number of results to return. You can use
nextTokento display the next page of results.
- On success, responds with
ListWorkgroupsOutputwith field(s):next_token(Option<String>):If
nextTokenis returned, there are more results available. The value ofnextTokenis a unique pagination token for each page. To retrieve the next page, make the call again using the returned token.workgroups(Option<Vec<Workgroup>>):The returned array of workgroups.
- On failure, responds with
SdkError<ListWorkgroupsError>
sourceimpl Client
impl Client
sourcepub fn put_resource_policy(&self) -> PutResourcePolicyFluentBuilder
pub fn put_resource_policy(&self) -> PutResourcePolicyFluentBuilder
Constructs a fluent builder for the PutResourcePolicy operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the account to create or update a resource policy for.
policy(impl Into<String>)/set_policy(Option<String>):The policy to create or update. For example, the following policy grants a user authorization to restore a snapshot.
“{"Version": "2012-10-17", "Statement" : [{ "Sid": "AllowUserRestoreFromSnapshot", "Principal":{"AWS": ["739247239426"]}, "Action": ["redshift-serverless:RestoreFromSnapshot"] , "Effect": "Allow" }]}”
- On success, responds with
PutResourcePolicyOutputwith field(s):resource_policy(Option<ResourcePolicy>):The policy that was created or updated.
- On failure, responds with
SdkError<PutResourcePolicyError>
sourceimpl Client
impl Client
sourcepub fn restore_from_recovery_point(
&self
) -> RestoreFromRecoveryPointFluentBuilder
pub fn restore_from_recovery_point( &self ) -> RestoreFromRecoveryPointFluentBuilder
Constructs a fluent builder for the RestoreFromRecoveryPoint operation.
- The fluent builder is configurable:
recovery_point_id(impl Into<String>)/set_recovery_point_id(Option<String>):The unique identifier of the recovery point to restore from.
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to restore data into.
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup used to restore data.
- On success, responds with
RestoreFromRecoveryPointOutputwith field(s):recovery_point_id(Option<String>):The unique identifier of the recovery point used for the restore.
namespace(Option<Namespace>):The namespace that data was restored into.
- On failure, responds with
SdkError<RestoreFromRecoveryPointError>
sourceimpl Client
impl Client
sourcepub fn restore_from_snapshot(&self) -> RestoreFromSnapshotFluentBuilder
pub fn restore_from_snapshot(&self) -> RestoreFromSnapshotFluentBuilder
Constructs a fluent builder for the RestoreFromSnapshot operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to restore the snapshot to.
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup used to restore the snapshot.
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot to restore from. Must not be specified at the same time as
snapshotArn.snapshot_arn(impl Into<String>)/set_snapshot_arn(Option<String>):The Amazon Resource Name (ARN) of the snapshot to restore from. Required if restoring from Amazon Redshift Serverless to a provisioned cluster. Must not be specified at the same time as
snapshotName.The format of the ARN is arn:aws:redshift:<region>:<account_id>:snapshot:<cluster_identifier>/<snapshot_identifier>.
owner_account(impl Into<String>)/set_owner_account(Option<String>):The Amazon Web Services account that owns the snapshot.
manage_admin_password(bool)/set_manage_admin_password(Option<bool>):If
true, Amazon Redshift uses Secrets Manager to manage the restored snapshot’s admin credentials. IfMmanageAdminPasswordis false or not set, Amazon Redshift uses the admin credentials that the namespace or cluster had at the time the snapshot was taken.admin_password_secret_kms_key_id(impl Into<String>)/set_admin_password_secret_kms_key_id(Option<String>):The ID of the Key Management Service (KMS) key used to encrypt and store the namespace’s admin credentials secret.
- On success, responds with
RestoreFromSnapshotOutputwith field(s):snapshot_name(Option<String>):The name of the snapshot used to restore the namespace.
owner_account(Option<String>):The owner Amazon Web Services; account of the snapshot that was restored.
namespace(Option<Namespace>):A collection of database objects and users.
- On failure, responds with
SdkError<RestoreFromSnapshotError>
sourceimpl Client
impl Client
sourcepub fn restore_table_from_snapshot(
&self
) -> RestoreTableFromSnapshotFluentBuilder
pub fn restore_table_from_snapshot( &self ) -> RestoreTableFromSnapshotFluentBuilder
Constructs a fluent builder for the RestoreTableFromSnapshot operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The namespace of the snapshot to restore from.
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The workgroup to restore the table to.
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot to restore the table from.
source_database_name(impl Into<String>)/set_source_database_name(Option<String>):The name of the source database that contains the table being restored.
source_schema_name(impl Into<String>)/set_source_schema_name(Option<String>):The name of the source schema that contains the table being restored.
source_table_name(impl Into<String>)/set_source_table_name(Option<String>):The name of the source table being restored.
target_database_name(impl Into<String>)/set_target_database_name(Option<String>):The name of the database to restore the table to.
target_schema_name(impl Into<String>)/set_target_schema_name(Option<String>):The name of the schema to restore the table to.
new_table_name(impl Into<String>)/set_new_table_name(Option<String>):The name of the table to create from the restore operation.
activate_case_sensitive_identifier(bool)/set_activate_case_sensitive_identifier(Option<bool>):Indicates whether name identifiers for database, schema, and table are case sensitive. If true, the names are case sensitive. If false, the names are not case sensitive. The default is false.
- On success, responds with
RestoreTableFromSnapshotOutputwith field(s):table_restore_status(Option<TableRestoreStatus>):The TableRestoreStatus object that contains the status of the restore operation.
- On failure, responds with
SdkError<RestoreTableFromSnapshotError>
sourceimpl Client
impl Client
sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the resource to tag.
tags(Tag)/set_tags(Option<Vec<Tag>>):The map of the key-value pairs used to tag the resource.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
sourceimpl Client
impl Client
sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):The Amazon Resource Name (ARN) of the resource to remove tags from.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec<String>>):The tag or set of tags to remove from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
sourceimpl Client
impl Client
sourcepub fn update_endpoint_access(&self) -> UpdateEndpointAccessFluentBuilder
pub fn update_endpoint_access(&self) -> UpdateEndpointAccessFluentBuilder
Constructs a fluent builder for the UpdateEndpointAccess operation.
- The fluent builder is configurable:
endpoint_name(impl Into<String>)/set_endpoint_name(Option<String>):The name of the VPC endpoint to update.
vpc_security_group_ids(impl Into<String>)/set_vpc_security_group_ids(Option<Vec<String>>):The list of VPC security groups associated with the endpoint after the endpoint is modified.
- On success, responds with
UpdateEndpointAccessOutputwith field(s):endpoint(Option<EndpointAccess>):The updated VPC endpoint.
- On failure, responds with
SdkError<UpdateEndpointAccessError>
sourceimpl Client
impl Client
sourcepub fn update_namespace(&self) -> UpdateNamespaceFluentBuilder
pub fn update_namespace(&self) -> UpdateNamespaceFluentBuilder
Constructs a fluent builder for the UpdateNamespace operation.
- The fluent builder is configurable:
namespace_name(impl Into<String>)/set_namespace_name(Option<String>):The name of the namespace to update. You can’t update the name of a namespace once it is created.
admin_user_password(impl Into<String>)/set_admin_user_password(Option<String>):The password of the administrator for the first database created in the namespace. This parameter must be updated together with
adminUsername.You can’t use
adminUserPasswordifmanageAdminPasswordis true.admin_username(impl Into<String>)/set_admin_username(Option<String>):The username of the administrator for the first database created in the namespace. This parameter must be updated together with
adminUserPassword.kms_key_id(impl Into<String>)/set_kms_key_id(Option<String>):The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
default_iam_role_arn(impl Into<String>)/set_default_iam_role_arn(Option<String>):The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace. This parameter must be updated together with
iamRoles.iam_roles(impl Into<String>)/set_iam_roles(Option<Vec<String>>):A list of IAM roles to associate with the namespace. This parameter must be updated together with
defaultIamRoleArn.log_exports(LogExport)/set_log_exports(Option<Vec<LogExport>>):The types of logs the namespace can export. The export types are
userlog,connectionlog, anduseractivitylog.manage_admin_password(bool)/set_manage_admin_password(Option<bool>):If
true, Amazon Redshift uses Secrets Manager to manage the namespace’s admin credentials. You can’t useadminUserPasswordifmanageAdminPasswordis true. IfmanageAdminPasswordis false or not set, Amazon Redshift usesadminUserPasswordfor the admin user account’s password.admin_password_secret_kms_key_id(impl Into<String>)/set_admin_password_secret_kms_key_id(Option<String>):The ID of the Key Management Service (KMS) key used to encrypt and store the namespace’s admin credentials secret. You can only use this parameter if
manageAdminPasswordis true.
- On success, responds with
UpdateNamespaceOutputwith field(s):namespace(Option<Namespace>):A list of tag instances.
- On failure, responds with
SdkError<UpdateNamespaceError>
sourceimpl Client
impl Client
sourcepub fn update_snapshot(&self) -> UpdateSnapshotFluentBuilder
pub fn update_snapshot(&self) -> UpdateSnapshotFluentBuilder
Constructs a fluent builder for the UpdateSnapshot operation.
- The fluent builder is configurable:
snapshot_name(impl Into<String>)/set_snapshot_name(Option<String>):The name of the snapshot.
retention_period(i32)/set_retention_period(Option<i32>):The new retention period of the snapshot.
- On success, responds with
UpdateSnapshotOutputwith field(s):snapshot(Option<Snapshot>):The updated snapshot object.
- On failure, responds with
SdkError<UpdateSnapshotError>
sourceimpl Client
impl Client
sourcepub fn update_usage_limit(&self) -> UpdateUsageLimitFluentBuilder
pub fn update_usage_limit(&self) -> UpdateUsageLimitFluentBuilder
Constructs a fluent builder for the UpdateUsageLimit operation.
- The fluent builder is configurable:
usage_limit_id(impl Into<String>)/set_usage_limit_id(Option<String>):The identifier of the usage limit to update.
amount(i64)/set_amount(Option<i64>):The new limit amount. If time-based, this amount is in Redshift Processing Units (RPU) consumed per hour. If data-based, this amount is in terabytes (TB) of data transferred between Regions in cross-account sharing. The value must be a positive number.
breach_action(UsageLimitBreachAction)/set_breach_action(Option<UsageLimitBreachAction>):The new action that Amazon Redshift Serverless takes when the limit is reached.
- On success, responds with
UpdateUsageLimitOutputwith field(s):usage_limit(Option<UsageLimit>):The updated usage limit object.
- On failure, responds with
SdkError<UpdateUsageLimitError>
sourceimpl Client
impl Client
sourcepub fn update_workgroup(&self) -> UpdateWorkgroupFluentBuilder
pub fn update_workgroup(&self) -> UpdateWorkgroupFluentBuilder
Constructs a fluent builder for the UpdateWorkgroup operation.
- The fluent builder is configurable:
workgroup_name(impl Into<String>)/set_workgroup_name(Option<String>):The name of the workgroup to update. You can’t update the name of a workgroup once it is created.
base_capacity(i32)/set_base_capacity(Option<i32>):The new base data warehouse capacity in Redshift Processing Units (RPUs).
enhanced_vpc_routing(bool)/set_enhanced_vpc_routing(Option<bool>):The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
config_parameters(ConfigParameter)/set_config_parameters(Option<Vec<ConfigParameter>>):An array of parameters to set for advanced control over a database. The options are
auto_mv,datestyle,enable_case_sensitivity_identifier,enable_user_activity_logging,query_group,search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.publicly_accessible(bool)/set_publicly_accessible(Option<bool>):A value that specifies whether the workgroup can be accessible from a public network.
subnet_ids(impl Into<String>)/set_subnet_ids(Option<Vec<String>>):An array of VPC subnet IDs to associate with the workgroup.
security_group_ids(impl Into<String>)/set_security_group_ids(Option<Vec<String>>):An array of security group IDs to associate with the workgroup.
port(i32)/set_port(Option<i32>):The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
- On success, responds with
UpdateWorkgroupOutputwith field(s):workgroup(Option<Workgroup>):The updated workgroup object.
- On failure, responds with
SdkError<UpdateWorkgroupError>
sourceimpl Client
impl Client
sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it.