#[non_exhaustive]pub struct NamespaceBuilder { /* private fields */ }Expand description
A builder for Namespace.
Implementations
Sourceimpl NamespaceBuilder
impl NamespaceBuilder
Sourcepub fn namespace_arn(self, input: impl Into<String>) -> Self
pub fn namespace_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) associated with a namespace.
Sourcepub fn set_namespace_arn(self, input: Option<String>) -> Self
pub fn set_namespace_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) associated with a namespace.
Sourcepub fn get_namespace_arn(&self) -> &Option<String>
pub fn get_namespace_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) associated with a namespace.
Sourcepub fn namespace_id(self, input: impl Into<String>) -> Self
pub fn namespace_id(self, input: impl Into<String>) -> Self
The unique identifier of a namespace.
Sourcepub fn set_namespace_id(self, input: Option<String>) -> Self
pub fn set_namespace_id(self, input: Option<String>) -> Self
The unique identifier of a namespace.
Sourcepub fn get_namespace_id(&self) -> &Option<String>
pub fn get_namespace_id(&self) -> &Option<String>
The unique identifier of a namespace.
Sourcepub fn namespace_name(self, input: impl Into<String>) -> Self
pub fn namespace_name(self, input: impl Into<String>) -> Self
The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
Sourcepub fn set_namespace_name(self, input: Option<String>) -> Self
pub fn set_namespace_name(self, input: Option<String>) -> Self
The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
Sourcepub fn get_namespace_name(&self) -> &Option<String>
pub fn get_namespace_name(&self) -> &Option<String>
The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
Sourcepub fn admin_username(self, input: impl Into<String>) -> Self
pub fn admin_username(self, input: impl Into<String>) -> Self
The username of the administrator for the first database created in the namespace.
Sourcepub fn set_admin_username(self, input: Option<String>) -> Self
pub fn set_admin_username(self, input: Option<String>) -> Self
The username of the administrator for the first database created in the namespace.
Sourcepub fn get_admin_username(&self) -> &Option<String>
pub fn get_admin_username(&self) -> &Option<String>
The username of the administrator for the first database created in the namespace.
Sourcepub fn db_name(self, input: impl Into<String>) -> Self
pub fn db_name(self, input: impl Into<String>) -> Self
The name of the first database created in the namespace.
Sourcepub fn set_db_name(self, input: Option<String>) -> Self
pub fn set_db_name(self, input: Option<String>) -> Self
The name of the first database created in the namespace.
Sourcepub fn get_db_name(&self) -> &Option<String>
pub fn get_db_name(&self) -> &Option<String>
The name of the first database created in the namespace.
Sourcepub fn kms_key_id(self, input: impl Into<String>) -> Self
pub fn kms_key_id(self, input: impl Into<String>) -> Self
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
Sourcepub fn set_kms_key_id(self, input: Option<String>) -> Self
pub fn set_kms_key_id(self, input: Option<String>) -> Self
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
Sourcepub fn get_kms_key_id(&self) -> &Option<String>
pub fn get_kms_key_id(&self) -> &Option<String>
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
Sourcepub fn default_iam_role_arn(self, input: impl Into<String>) -> Self
pub fn default_iam_role_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
Sourcepub fn set_default_iam_role_arn(self, input: Option<String>) -> Self
pub fn set_default_iam_role_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
Sourcepub fn get_default_iam_role_arn(&self) -> &Option<String>
pub fn get_default_iam_role_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
Sourcepub fn iam_roles(self, input: impl Into<String>) -> Self
pub fn iam_roles(self, input: impl Into<String>) -> Self
Appends an item to iam_roles.
To override the contents of this collection use set_iam_roles.
A list of IAM roles to associate with the namespace.
Sourcepub fn set_iam_roles(self, input: Option<Vec<String>>) -> Self
pub fn set_iam_roles(self, input: Option<Vec<String>>) -> Self
A list of IAM roles to associate with the namespace.
Sourcepub fn get_iam_roles(&self) -> &Option<Vec<String>>
pub fn get_iam_roles(&self) -> &Option<Vec<String>>
A list of IAM roles to associate with the namespace.
Sourcepub fn log_exports(self, input: LogExport) -> Self
pub fn log_exports(self, input: LogExport) -> Self
Appends an item to log_exports.
To override the contents of this collection use set_log_exports.
The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
Sourcepub fn set_log_exports(self, input: Option<Vec<LogExport>>) -> Self
pub fn set_log_exports(self, input: Option<Vec<LogExport>>) -> Self
The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
Sourcepub fn get_log_exports(&self) -> &Option<Vec<LogExport>>
pub fn get_log_exports(&self) -> &Option<Vec<LogExport>>
The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
Sourcepub fn status(self, input: NamespaceStatus) -> Self
pub fn status(self, input: NamespaceStatus) -> Self
The status of the namespace.
Sourcepub fn set_status(self, input: Option<NamespaceStatus>) -> Self
pub fn set_status(self, input: Option<NamespaceStatus>) -> Self
The status of the namespace.
Sourcepub fn get_status(&self) -> &Option<NamespaceStatus>
pub fn get_status(&self) -> &Option<NamespaceStatus>
The status of the namespace.
Sourcepub fn creation_date(self, input: DateTime) -> Self
pub fn creation_date(self, input: DateTime) -> Self
The date of when the namespace was created.
Sourcepub fn set_creation_date(self, input: Option<DateTime>) -> Self
pub fn set_creation_date(self, input: Option<DateTime>) -> Self
The date of when the namespace was created.
Sourcepub fn get_creation_date(&self) -> &Option<DateTime>
pub fn get_creation_date(&self) -> &Option<DateTime>
The date of when the namespace was created.
Sourcepub fn admin_password_secret_arn(self, input: impl Into<String>) -> Self
pub fn admin_password_secret_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
Sourcepub fn set_admin_password_secret_arn(self, input: Option<String>) -> Self
pub fn set_admin_password_secret_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
Sourcepub fn get_admin_password_secret_arn(&self) -> &Option<String>
pub fn get_admin_password_secret_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
Sourcepub fn admin_password_secret_kms_key_id(self, input: impl Into<String>) -> Self
pub fn admin_password_secret_kms_key_id(self, input: impl Into<String>) -> Self
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
Sourcepub fn set_admin_password_secret_kms_key_id(self, input: Option<String>) -> Self
pub fn set_admin_password_secret_kms_key_id(self, input: Option<String>) -> Self
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
Sourcepub fn get_admin_password_secret_kms_key_id(&self) -> &Option<String>
pub fn get_admin_password_secret_kms_key_id(&self) -> &Option<String>
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
Sourcepub fn lakehouse_registration_status(self, input: impl Into<String>) -> Self
pub fn lakehouse_registration_status(self, input: impl Into<String>) -> Self
The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.
Sourcepub fn set_lakehouse_registration_status(self, input: Option<String>) -> Self
pub fn set_lakehouse_registration_status(self, input: Option<String>) -> Self
The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.
Sourcepub fn get_lakehouse_registration_status(&self) -> &Option<String>
pub fn get_lakehouse_registration_status(&self) -> &Option<String>
The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.
Sourcepub fn catalog_arn(self, input: impl Into<String>) -> Self
pub fn catalog_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.
Sourcepub fn set_catalog_arn(self, input: Option<String>) -> Self
pub fn set_catalog_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.
Sourcepub fn get_catalog_arn(&self) -> &Option<String>
pub fn get_catalog_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.