Struct aws_sdk_redshiftserverless::types::ConfigParameter
source · #[non_exhaustive]pub struct ConfigParameter {
pub parameter_key: Option<String>,
pub parameter_value: Option<String>,
}Expand description
An array of key-value pairs to set for advanced control over Amazon Redshift Serverless.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parameter_key: Option<String>The key of the parameter. The options are auto_mv, datestyle, enable_case_sensitivity_identifier, enable_user_activity_logging, query_group, search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
parameter_value: Option<String>The value of the parameter to set.
Implementations
sourceimpl ConfigParameter
impl ConfigParameter
sourcepub fn parameter_key(&self) -> Option<&str>
pub fn parameter_key(&self) -> Option<&str>
The key of the parameter. The options are auto_mv, datestyle, enable_case_sensitivity_identifier, enable_user_activity_logging, query_group, search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
sourcepub fn parameter_value(&self) -> Option<&str>
pub fn parameter_value(&self) -> Option<&str>
The value of the parameter to set.
sourceimpl ConfigParameter
impl ConfigParameter
sourcepub fn builder() -> ConfigParameterBuilder
pub fn builder() -> ConfigParameterBuilder
Creates a new builder-style object to manufacture ConfigParameter.