#[non_exhaustive]pub struct Namespace {Show 15 fields
pub namespace_arn: Option<String>,
pub namespace_id: Option<String>,
pub namespace_name: Option<String>,
pub admin_username: Option<String>,
pub db_name: Option<String>,
pub kms_key_id: Option<String>,
pub default_iam_role_arn: Option<String>,
pub iam_roles: Option<Vec<String>>,
pub log_exports: Option<Vec<LogExport>>,
pub status: Option<NamespaceStatus>,
pub creation_date: Option<DateTime>,
pub admin_password_secret_arn: Option<String>,
pub admin_password_secret_kms_key_id: Option<String>,
pub lakehouse_registration_status: Option<String>,
pub catalog_arn: Option<String>,
}Expand description
A collection of database objects and users.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespace_arn: Option<String>The Amazon Resource Name (ARN) associated with a namespace.
namespace_id: Option<String>The unique identifier of a namespace.
namespace_name: Option<String>The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
admin_username: Option<String>The username of the administrator for the first database created in the namespace.
db_name: Option<String>The name of the first database created in the namespace.
kms_key_id: Option<String>The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
default_iam_role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
iam_roles: Option<Vec<String>>A list of IAM roles to associate with the namespace.
log_exports: Option<Vec<LogExport>>The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
status: Option<NamespaceStatus>The status of the namespace.
creation_date: Option<DateTime>The date of when the namespace was created.
admin_password_secret_arn: Option<String>The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
admin_password_secret_kms_key_id: Option<String>The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
lakehouse_registration_status: Option<String>The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.
catalog_arn: Option<String>The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.
Implementations
Sourceimpl Namespace
impl Namespace
Sourcepub fn namespace_arn(&self) -> Option<&str>
pub fn namespace_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) associated with a namespace.
Sourcepub fn namespace_id(&self) -> Option<&str>
pub fn namespace_id(&self) -> Option<&str>
The unique identifier of a namespace.
Sourcepub fn namespace_name(&self) -> Option<&str>
pub fn namespace_name(&self) -> Option<&str>
The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
Sourcepub fn admin_username(&self) -> Option<&str>
pub fn admin_username(&self) -> Option<&str>
The username of the administrator for the first database created in the namespace.
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
Sourcepub fn default_iam_role_arn(&self) -> Option<&str>
pub fn default_iam_role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
Sourcepub fn iam_roles(&self) -> &[String]
pub fn iam_roles(&self) -> &[String]
A list of IAM roles to associate with the namespace.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .iam_roles.is_none().
Sourcepub fn log_exports(&self) -> &[LogExport]
pub fn log_exports(&self) -> &[LogExport]
The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .log_exports.is_none().
Sourcepub fn status(&self) -> Option<&NamespaceStatus>
pub fn status(&self) -> Option<&NamespaceStatus>
The status of the namespace.
Sourcepub fn creation_date(&self) -> Option<&DateTime>
pub fn creation_date(&self) -> Option<&DateTime>
The date of when the namespace was created.
Sourcepub fn admin_password_secret_arn(&self) -> Option<&str>
pub fn admin_password_secret_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
Sourcepub fn admin_password_secret_kms_key_id(&self) -> Option<&str>
pub fn admin_password_secret_kms_key_id(&self) -> Option<&str>
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
Sourcepub fn lakehouse_registration_status(&self) -> Option<&str>
pub fn lakehouse_registration_status(&self) -> Option<&str>
The status of the lakehouse registration for the namespace. Indicates whether the namespace is successfully registered with Amazon Redshift federated permissions.
Sourcepub fn catalog_arn(&self) -> Option<&str>
pub fn catalog_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the Glue Data Catalog associated with the namespace enabled with Amazon Redshift federated permissions.