#[non_exhaustive]pub struct S3TablePublishStatus {
pub s3_tables: Option<Vec<String>>,
pub s3_table_namespace: Option<String>,
pub s3_table_granularity: Option<S3TableGranularity>,
pub enabled_all: Option<bool>,
pub last_ingestion_times: Option<HashMap<String, String>>,
}Expand description
Describes the state of Amazon S3 Tables system-table log publishing for a namespace.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.s3_tables: Option<Vec<String>>The system tables currently being published.
s3_table_namespace: Option<String>The identifier of the namespace in the S3 table bucket that holds the published tables.
s3_table_granularity: Option<S3TableGranularity>The scope currently in effect. Values are namespace or account.
enabled_all: Option<bool>true when the namespace is enrolled in every current and future system table rather than an explicit list of tables.
last_ingestion_times: Option<HashMap<String, String>>A map of system table name to the time that table last received data, as an ISO-8601 timestamp. A table that has not yet been ingested is absent from the map. Use it to judge data freshness.
Implementations
Sourceimpl S3TablePublishStatus
impl S3TablePublishStatus
Sourcepub fn s3_tables(&self) -> &[String]
pub fn s3_tables(&self) -> &[String]
The system tables currently being published.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .s3_tables.is_none().
Sourcepub fn s3_table_namespace(&self) -> Option<&str>
pub fn s3_table_namespace(&self) -> Option<&str>
The identifier of the namespace in the S3 table bucket that holds the published tables.
Sourcepub fn s3_table_granularity(&self) -> Option<&S3TableGranularity>
pub fn s3_table_granularity(&self) -> Option<&S3TableGranularity>
The scope currently in effect. Values are namespace or account.
Sourcepub fn enabled_all(&self) -> Option<bool>
pub fn enabled_all(&self) -> Option<bool>
true when the namespace is enrolled in every current and future system table rather than an explicit list of tables.
Sourceimpl S3TablePublishStatus
impl S3TablePublishStatus
Sourcepub fn builder() -> S3TablePublishStatusBuilder
pub fn builder() -> S3TablePublishStatusBuilder
Creates a new builder-style object to manufacture S3TablePublishStatus.