Struct aws_sdk_redshiftserverless::types::Namespace
source · #[non_exhaustive]pub struct Namespace {Show 13 fields
pub namespace_arn: Option<String>,
pub namespace_id: Option<String>,
pub namespace_name: Option<String>,
pub admin_username: Option<String>,
pub db_name: Option<String>,
pub kms_key_id: Option<String>,
pub default_iam_role_arn: Option<String>,
pub iam_roles: Option<Vec<String>>,
pub log_exports: Option<Vec<LogExport>>,
pub status: Option<NamespaceStatus>,
pub creation_date: Option<DateTime>,
pub admin_password_secret_arn: Option<String>,
pub admin_password_secret_kms_key_id: Option<String>,
}Expand description
A collection of database objects and users.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.namespace_arn: Option<String>The Amazon Resource Name (ARN) associated with a namespace.
namespace_id: Option<String>The unique identifier of a namespace.
namespace_name: Option<String>The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
admin_username: Option<String>The username of the administrator for the first database created in the namespace.
db_name: Option<String>The name of the first database created in the namespace.
kms_key_id: Option<String>The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
default_iam_role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
iam_roles: Option<Vec<String>>A list of IAM roles to associate with the namespace.
log_exports: Option<Vec<LogExport>>The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
status: Option<NamespaceStatus>The status of the namespace.
creation_date: Option<DateTime>The date of when the namespace was created.
admin_password_secret_arn: Option<String>The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
admin_password_secret_kms_key_id: Option<String>The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.
Implementations
sourceimpl Namespace
impl Namespace
sourcepub fn namespace_arn(&self) -> Option<&str>
pub fn namespace_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) associated with a namespace.
sourcepub fn namespace_id(&self) -> Option<&str>
pub fn namespace_id(&self) -> Option<&str>
The unique identifier of a namespace.
sourcepub fn namespace_name(&self) -> Option<&str>
pub fn namespace_name(&self) -> Option<&str>
The name of the namespace. Must be between 3-64 alphanumeric characters in lowercase, and it cannot be a reserved word. A list of reserved words can be found in Reserved Words in the Amazon Redshift Database Developer Guide.
sourcepub fn admin_username(&self) -> Option<&str>
pub fn admin_username(&self) -> Option<&str>
The username of the administrator for the first database created in the namespace.
sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
sourcepub fn default_iam_role_arn(&self) -> Option<&str>
pub fn default_iam_role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
sourcepub fn iam_roles(&self) -> Option<&[String]>
pub fn iam_roles(&self) -> Option<&[String]>
A list of IAM roles to associate with the namespace.
sourcepub fn log_exports(&self) -> Option<&[LogExport]>
pub fn log_exports(&self) -> Option<&[LogExport]>
The types of logs the namespace can export. Available export types are User log, Connection log, and User activity log.
sourcepub fn status(&self) -> Option<&NamespaceStatus>
pub fn status(&self) -> Option<&NamespaceStatus>
The status of the namespace.
sourcepub fn creation_date(&self) -> Option<&DateTime>
pub fn creation_date(&self) -> Option<&DateTime>
The date of when the namespace was created.
sourcepub fn admin_password_secret_arn(&self) -> Option<&str>
pub fn admin_password_secret_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) for the namespace's admin user credentials secret.
sourcepub fn admin_password_secret_kms_key_id(&self) -> Option<&str>
pub fn admin_password_secret_kms_key_id(&self) -> Option<&str>
The ID of the Key Management Service (KMS) key used to encrypt and store the namespace's admin credentials secret.