#[non_exhaustive]pub struct Workgroup {Show 26 fields
pub workgroup_id: Option<String>,
pub workgroup_arn: Option<String>,
pub workgroup_name: Option<String>,
pub namespace_name: Option<String>,
pub base_capacity: Option<i32>,
pub enhanced_vpc_routing: Option<bool>,
pub config_parameters: Option<Vec<ConfigParameter>>,
pub security_group_ids: Option<Vec<String>>,
pub subnet_ids: Option<Vec<String>>,
pub status: Option<WorkgroupStatus>,
pub endpoint: Option<Endpoint>,
pub publicly_accessible: Option<bool>,
pub creation_date: Option<DateTime>,
pub port: Option<i32>,
pub custom_domain_name: Option<String>,
pub custom_domain_certificate_arn: Option<String>,
pub custom_domain_certificate_expiry_time: Option<DateTime>,
pub workgroup_version: Option<String>,
pub patch_version: Option<String>,
pub max_capacity: Option<i32>,
pub cross_account_vpcs: Option<Vec<String>>,
pub ip_address_type: Option<String>,
pub price_performance_target: Option<PerformanceTarget>,
pub track_name: Option<String>,
pub pending_track_name: Option<String>,
pub extra_compute_for_automatic_optimization: Option<bool>,
}Expand description
The collection of computing resources from which an endpoint is created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workgroup_id: Option<String>The unique identifier of the workgroup.
workgroup_arn: Option<String>The Amazon Resource Name (ARN) that links to the workgroup.
workgroup_name: Option<String>The name of the workgroup.
namespace_name: Option<String>The namespace the workgroup is associated with.
base_capacity: Option<i32>The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
enhanced_vpc_routing: Option<bool>The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
config_parameters: Option<Vec<ConfigParameter>>An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
security_group_ids: Option<Vec<String>>An array of security group IDs to associate with the workgroup.
subnet_ids: Option<Vec<String>>An array of subnet IDs the workgroup is associated with.
status: Option<WorkgroupStatus>The status of the workgroup.
endpoint: Option<Endpoint>The endpoint that is created from the workgroup.
publicly_accessible: Option<bool>A value that specifies whether the workgroup can be accessible from a public network.
creation_date: Option<DateTime>The creation date of the workgroup.
port: Option<i32>The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
custom_domain_name: Option<String>The custom domain name associated with the workgroup.
custom_domain_certificate_arn: Option<String>The custom domain name’s certificate Amazon resource name (ARN).
custom_domain_certificate_expiry_time: Option<DateTime>The expiration time for the certificate.
workgroup_version: Option<String>The Amazon Redshift Serverless version of your workgroup. For more information about Amazon Redshift Serverless versions, seeCluster versions for Amazon Redshift.
patch_version: Option<String>The patch version of your Amazon Redshift Serverless workgroup. For more information about patch versions, see Cluster versions for Amazon Redshift.
max_capacity: Option<i32>The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.
cross_account_vpcs: Option<Vec<String>>A list of VPCs. Each entry is the unique identifier of a virtual private cloud with access to Amazon Redshift Serverless. If all of the VPCs for the grantee are allowed, it shows an asterisk.
ip_address_type: Option<String>The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.
price_performance_target: Option<PerformanceTarget>An object that represents the price performance target settings for the workgroup.
track_name: Option<String>The name of the track for the workgroup.
pending_track_name: Option<String>The name for the track that you want to assign to the workgroup. When the track changes, the workgroup is switched to the latest workgroup release available for the track. At this point, the track name is applied.
extra_compute_for_automatic_optimization: Option<bool>A boolean value that, if true, indicates that the workgroup allocates additional compute resources to run automatic optimization operations.
Default: false
Implementations
Sourceimpl Workgroup
impl Workgroup
Sourcepub fn workgroup_id(&self) -> Option<&str>
pub fn workgroup_id(&self) -> Option<&str>
The unique identifier of the workgroup.
Sourcepub fn workgroup_arn(&self) -> Option<&str>
pub fn workgroup_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) that links to the workgroup.
Sourcepub fn workgroup_name(&self) -> Option<&str>
pub fn workgroup_name(&self) -> Option<&str>
The name of the workgroup.
Sourcepub fn namespace_name(&self) -> Option<&str>
pub fn namespace_name(&self) -> Option<&str>
The namespace the workgroup is associated with.
Sourcepub fn base_capacity(&self) -> Option<i32>
pub fn base_capacity(&self) -> Option<i32>
The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
Sourcepub fn enhanced_vpc_routing(&self) -> Option<bool>
pub fn enhanced_vpc_routing(&self) -> Option<bool>
The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
Sourcepub fn config_parameters(&self) -> &[ConfigParameter]
pub fn config_parameters(&self) -> &[ConfigParameter]
An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitive_identifier, enable_user_activity_logging, query_group, search_path, require_ssl, use_fips_ssl, and either wlm_json_configuration or query monitoring metrics that let you define performance boundaries. You can either specify individual query monitoring metrics (such as max_scan_row_count, max_query_execution_time) or use wlm_json_configuration to define query queues with rules, but not both. If you're using wlm_json_configuration, the maximum size of parameterValue is 8000 characters. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .config_parameters.is_none().
Sourcepub fn security_group_ids(&self) -> &[String]
pub fn security_group_ids(&self) -> &[String]
An array of security group IDs to associate with the workgroup.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .security_group_ids.is_none().
Sourcepub fn subnet_ids(&self) -> &[String]
pub fn subnet_ids(&self) -> &[String]
An array of subnet IDs the workgroup is associated with.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .subnet_ids.is_none().
Sourcepub fn status(&self) -> Option<&WorkgroupStatus>
pub fn status(&self) -> Option<&WorkgroupStatus>
The status of the workgroup.
Sourcepub fn publicly_accessible(&self) -> Option<bool>
pub fn publicly_accessible(&self) -> Option<bool>
A value that specifies whether the workgroup can be accessible from a public network.
Sourcepub fn creation_date(&self) -> Option<&DateTime>
pub fn creation_date(&self) -> Option<&DateTime>
The creation date of the workgroup.
Sourcepub fn port(&self) -> Option<i32>
pub fn port(&self) -> Option<i32>
The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
Sourcepub fn custom_domain_name(&self) -> Option<&str>
pub fn custom_domain_name(&self) -> Option<&str>
The custom domain name associated with the workgroup.
Sourcepub fn custom_domain_certificate_arn(&self) -> Option<&str>
pub fn custom_domain_certificate_arn(&self) -> Option<&str>
The custom domain name’s certificate Amazon resource name (ARN).
Sourcepub fn custom_domain_certificate_expiry_time(&self) -> Option<&DateTime>
pub fn custom_domain_certificate_expiry_time(&self) -> Option<&DateTime>
The expiration time for the certificate.
Sourcepub fn workgroup_version(&self) -> Option<&str>
pub fn workgroup_version(&self) -> Option<&str>
The Amazon Redshift Serverless version of your workgroup. For more information about Amazon Redshift Serverless versions, seeCluster versions for Amazon Redshift.
Sourcepub fn patch_version(&self) -> Option<&str>
pub fn patch_version(&self) -> Option<&str>
The patch version of your Amazon Redshift Serverless workgroup. For more information about patch versions, see Cluster versions for Amazon Redshift.
Sourcepub fn max_capacity(&self) -> Option<i32>
pub fn max_capacity(&self) -> Option<i32>
The maximum data-warehouse capacity Amazon Redshift Serverless uses to serve queries. The max capacity is specified in RPUs.
Sourcepub fn cross_account_vpcs(&self) -> &[String]
pub fn cross_account_vpcs(&self) -> &[String]
A list of VPCs. Each entry is the unique identifier of a virtual private cloud with access to Amazon Redshift Serverless. If all of the VPCs for the grantee are allowed, it shows an asterisk.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .cross_account_vpcs.is_none().
Sourcepub fn ip_address_type(&self) -> Option<&str>
pub fn ip_address_type(&self) -> Option<&str>
The IP address type that the workgroup supports. Possible values are ipv4 and dualstack.
Sourcepub fn price_performance_target(&self) -> Option<&PerformanceTarget>
pub fn price_performance_target(&self) -> Option<&PerformanceTarget>
An object that represents the price performance target settings for the workgroup.
Sourcepub fn track_name(&self) -> Option<&str>
pub fn track_name(&self) -> Option<&str>
The name of the track for the workgroup.
Sourcepub fn pending_track_name(&self) -> Option<&str>
pub fn pending_track_name(&self) -> Option<&str>
The name for the track that you want to assign to the workgroup. When the track changes, the workgroup is switched to the latest workgroup release available for the track. At this point, the track name is applied.
Sourcepub fn extra_compute_for_automatic_optimization(&self) -> Option<bool>
pub fn extra_compute_for_automatic_optimization(&self) -> Option<bool>
A boolean value that, if true, indicates that the workgroup allocates additional compute resources to run automatic optimization operations.
Default: false