Struct aws_sdk_redshiftserverless::types::Workgroup
source · #[non_exhaustive]pub struct Workgroup {Show 16 fields
pub workgroup_id: Option<String>,
pub workgroup_arn: Option<String>,
pub workgroup_name: Option<String>,
pub namespace_name: Option<String>,
pub base_capacity: Option<i32>,
pub enhanced_vpc_routing: Option<bool>,
pub config_parameters: Option<Vec<ConfigParameter>>,
pub security_group_ids: Option<Vec<String>>,
pub subnet_ids: Option<Vec<String>>,
pub status: Option<WorkgroupStatus>,
pub endpoint: Option<Endpoint>,
pub publicly_accessible: Option<bool>,
pub creation_date: Option<DateTime>,
pub port: Option<i32>,
pub workgroup_version: Option<String>,
pub patch_version: Option<String>,
}Expand description
The collection of computing resources from which an endpoint is created.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.workgroup_id: Option<String>The unique identifier of the workgroup.
workgroup_arn: Option<String>The Amazon Resource Name (ARN) that links to the workgroup.
workgroup_name: Option<String>The name of the workgroup.
namespace_name: Option<String>The namespace the workgroup is associated with.
base_capacity: Option<i32>The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
enhanced_vpc_routing: Option<bool>The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
config_parameters: Option<Vec<ConfigParameter>>An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitivity_identifier, enable_user_activity_logging, query_group, , search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
security_group_ids: Option<Vec<String>>An array of security group IDs to associate with the workgroup.
subnet_ids: Option<Vec<String>>An array of subnet IDs the workgroup is associated with.
status: Option<WorkgroupStatus>The status of the workgroup.
endpoint: Option<Endpoint>The endpoint that is created from the workgroup.
publicly_accessible: Option<bool>A value that specifies whether the workgroup can be accessible from a public network
creation_date: Option<DateTime>The creation date of the workgroup.
port: Option<i32>The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
workgroup_version: Option<String>The Amazon Redshift Serverless version of your workgroup. For more information about Amazon Redshift Serverless versions, seeCluster versions for Amazon Redshift.
patch_version: Option<String>The patch version of your Amazon Redshift Serverless workgroup. For more information about patch versions, see Cluster versions for Amazon Redshift.
Implementations
sourceimpl Workgroup
impl Workgroup
sourcepub fn workgroup_id(&self) -> Option<&str>
pub fn workgroup_id(&self) -> Option<&str>
The unique identifier of the workgroup.
sourcepub fn workgroup_arn(&self) -> Option<&str>
pub fn workgroup_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) that links to the workgroup.
sourcepub fn workgroup_name(&self) -> Option<&str>
pub fn workgroup_name(&self) -> Option<&str>
The name of the workgroup.
sourcepub fn namespace_name(&self) -> Option<&str>
pub fn namespace_name(&self) -> Option<&str>
The namespace the workgroup is associated with.
sourcepub fn base_capacity(&self) -> Option<i32>
pub fn base_capacity(&self) -> Option<i32>
The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
sourcepub fn enhanced_vpc_routing(&self) -> Option<bool>
pub fn enhanced_vpc_routing(&self) -> Option<bool>
The value that specifies whether to enable enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
sourcepub fn config_parameters(&self) -> Option<&[ConfigParameter]>
pub fn config_parameters(&self) -> Option<&[ConfigParameter]>
An array of parameters to set for advanced control over a database. The options are auto_mv, datestyle, enable_case_sensitivity_identifier, enable_user_activity_logging, query_group, , search_path, and query monitoring metrics that let you define performance boundaries. For more information about query monitoring rules and available metrics, see Query monitoring metrics for Amazon Redshift Serverless.
sourcepub fn security_group_ids(&self) -> Option<&[String]>
pub fn security_group_ids(&self) -> Option<&[String]>
An array of security group IDs to associate with the workgroup.
sourcepub fn subnet_ids(&self) -> Option<&[String]>
pub fn subnet_ids(&self) -> Option<&[String]>
An array of subnet IDs the workgroup is associated with.
sourcepub fn status(&self) -> Option<&WorkgroupStatus>
pub fn status(&self) -> Option<&WorkgroupStatus>
The status of the workgroup.
sourcepub fn publicly_accessible(&self) -> Option<bool>
pub fn publicly_accessible(&self) -> Option<bool>
A value that specifies whether the workgroup can be accessible from a public network
sourcepub fn creation_date(&self) -> Option<&DateTime>
pub fn creation_date(&self) -> Option<&DateTime>
The creation date of the workgroup.
sourcepub fn port(&self) -> Option<i32>
pub fn port(&self) -> Option<i32>
The custom port to use when connecting to a workgroup. Valid port ranges are 5431-5455 and 8191-8215. The default is 5439.
sourcepub fn workgroup_version(&self) -> Option<&str>
pub fn workgroup_version(&self) -> Option<&str>
The Amazon Redshift Serverless version of your workgroup. For more information about Amazon Redshift Serverless versions, seeCluster versions for Amazon Redshift.
sourcepub fn patch_version(&self) -> Option<&str>
pub fn patch_version(&self) -> Option<&str>
The patch version of your Amazon Redshift Serverless workgroup. For more information about patch versions, see Cluster versions for Amazon Redshift.